@@ -1,4 +1,5 @@
-from hashlib import md5
+from hashlib  import md5
+from warnings import warn
 
 import numpy as np
 from numpy.random import RandomState
@@ -21,6 +22,11 @@ def min_max(it):
     return min_, max_
 
 
+def warn_size(n: int, limit: int=20):
+    if n > limit:
+        warn('This operation may take a very long time for n>{limit}.')
+
+
 def get_random_state(state=None):
     if isinstance(state, RandomState):
         return state
